@@ -25,6 +25,8 @@ from typing import TYPE_CHECKING
 
 import attr
 
+from thoth.common import get_justification_link as jl
+
 from ..boot import Boot
 
 if TYPE_CHECKING:
@@ -37,6 +39,9 @@ _LOGGER = logging.getLogger(__name__)
 class PythonVersionBoot(Boot):
     """A boot that checks Python3 configuration used by user."""
 
+    _LINK_PY_VER_PIPFILE = jl("py_version")
+    _LINK_PY_VER_THOTH_CONF = jl("py_version")
+
     @classmethod
     def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
         """Register self, always for adviser."""
@@ -57,14 +62,14 @@ class PythonVersionBoot(Boot):
                 f"No version of Python specified in the configuration, using Python version "
                 f"found in Pipfile: {pipfile_python_version!r}"
             )
-            _LOGGER.warning(msg)
+            _LOGGER.warning("%s - see %s", msg, self._LINK_PY_VER_PIPFILE)
             self.context.project.runtime_environment.python_version = pipfile_python_version
-            self.context.stack_info.append({"type": "WARNING", "Message": msg})
+            self.context.stack_info.append({"type": "WARNING", "message": msg, "link": self._LINK_PY_VER_PIPFILE})
         elif python_version is not None and pipfile_python_version is None:
             msg = (
                 f"No version of Python specified explicitly, assigning the one found in "
                 f"Thoth's configuration: {python_version!r}"
             )
-            _LOGGER.warning(msg)
+            _LOGGER.warning("%s - see %s", msg, self._LINK_PY_VER_THOTH_CONF)
             self.context.project.pipfile.meta.requires["python_version"] = python_version
-            self.context.stack_info.append({"type": "WARNING", "Message": msg})
+            self.context.stack_info.append({"type": "WARNING", "message": msg, "link": self._LINK_PY_VER_THOTH_CONF})
